@@ -5,26 +5,30 @@ import logging as _logging
 import numbers
 import re
 import warnings
-from collections.abc import Callable
 from pathlib import Path
 from string import printable
 from textwrap import dedent
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 from streamlink import __version__ as streamlink_version, logger
 from streamlink.exceptions import StreamlinkDeprecationWarning
 from streamlink.options import Options
-from streamlink.plugin import Plugin
-from streamlink.session import Streamlink
-from streamlink.user_input import UserInputRequester
 from streamlink.utils.args import boolean, comma_list, comma_list_filter, filesize, keyvalue, num
 from streamlink.utils.times import hours_minutes_seconds_float
 from streamlink_cli.constants import STREAM_PASSTHROUGH
 from streamlink_cli.exceptions import StreamlinkCLIError
-from streamlink_cli.output.player import PlayerOutput
+from streamlink_cli.output.player import PlayerArgs, PlayerOutput
 from streamlink_cli.utils import find_default_player
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+    from streamlink.plugin import Plugin
+    from streamlink.session import Streamlink
+    from streamlink.user_input import UserInputRequester
+
+
 log = _logging.getLogger(__name__)
 
 
@@ -37,6 +41,7 @@ class ArgumentParser(argparse.ArgumentParser):
 
     def __init__(self, *args, **kwargs):
         self.NESTED_ARGUMENT_GROUPS = {}
+        self.color = True  # pre 3.14 compat
         super().__init__(*args, **kwargs)
 
     # noinspection PyUnresolvedReferences,PyProtectedMember
@@ -105,6 +110,15 @@ class ArgumentParser(argparse.ArgumentParser):
         # return the number of arguments matched
         return len(match.group(1))
 
+    # disable color output for the "usage" text
+    def format_usage(self):
+        color = self.color
+        self.color = False
+        try:
+            return super().format_usage()
+        finally:
+            self.color = color
+
     # fix `--help` not including nested argument groups
     def format_help(self):
         formatter = self._get_formatter()
@@ -242,60 +256,6 @@ def build_parser():
             Default is "no".
         """,
     )
-    general.add_argument(
-        "--plugins",
-        action="store_true",
-        help="""
-            Print a list of all currently installed plugins.
-        """,
-    )
-    general.add_argument(
-        "--plugin-dir",
-        dest="plugin_dirs",
-        metavar="DIRECTORY",
-        action="append",
-        help="""
-            Load plugins from this directory.
-
-            Can be set multiple times to load plugins from multiple directories.
-        """,
-    )
-    general.add_argument(
-        "--plugin-dirs",
-        metavar="DIRECTORY",
-        type=comma_list,
-        action="extend",
-        help="""
-            Load plugins from a list of comma-separated directories. (deprecated)
-        """,
-    )
-    general.add_argument(
-        "--show-matchers",
-        metavar="PLUGIN",
-        help="""
-            Show the list of matchers of a specific plugin (URL regex pattern with opt. priority and opt. name).
-
-            The output is a human-readable pseudo YAML format. Please use --json when reading matcher data programmatically.
-        """,
-    )
-    general.add_argument(
-        "--can-handle-url",
-        metavar="URL",
-        help="""
-            Check if Streamlink has a plugin that can handle the specified URL.
-
-            Status code is `0` on success, `1` on failure.
-
-            Useful for external scripting.
-        """,
-    )
-    general.add_argument(
-        "--can-handle-url-no-redirect",
-        metavar="URL",
-        help="""
-            Same as --can-handle-url, but without following redirects when looking up the URL.
-        """,
-    )
     general.add_argument(
         "--config",
         action="append",
@@ -357,7 +317,7 @@ def build_parser():
 
             For verbose levels (`trace` and `all`):
 
-            Default is "[{asctime}][{name}][{levelname}] {message}".
+            Default is "[{asctime}][{threadName}][{name}][{levelname}] {message}".
 
             Otherwise:
 
@@ -412,9 +372,7 @@ def build_parser():
         "--quiet",
         action="store_true",
         help="""
-            Hide all log output.
-
-            Alias for --loglevel=none.
+            Suppress all console and log output, and also disable user prompts.
         """,
     )
     logging.add_argument(
@@ -428,6 +386,82 @@ def build_parser():
         """,
     )
 
+    plugin = parser.add_argument_group("Plugin options")
+    plugin.add_argument(
+        "--plugins",
+        action="store_true",
+        help="""
+            Print a list of all currently installed plugins.
+        """,
+    )
+    plugin.add_argument(
+        "--show-matchers",
+        metavar="PLUGIN",
+        help="""
+            Show the list of matchers of a specific plugin (URL regex pattern with opt. priority and opt. name).
+
+            The output is a human-readable pseudo YAML format. Please use --json when reading matcher data programmatically.
+        """,
+    )
+    plugin.add_argument(
+        "--can-handle-url",
+        metavar="URL",
+        help="""
+            Check if Streamlink has a plugin that can handle the specified URL.
+
+            Status code is `0` on success, `1` on failure.
+
+            Useful for external scripting.
+        """,
+    )
+    plugin.add_argument(
+        "--can-handle-url-no-redirect",
+        metavar="URL",
+        help="""
+            Same as --can-handle-url, but without following redirects when looking up the URL.
+        """,
+    )
+    plugin.add_argument(
+        "--no-plugin-cache",
+        action="store_true",
+        default=None,
+        help="""
+            Disable I/O of the plugin key-value store.
+
+            If disabled, plugins won't be able to load or store data like cookies, authentication data, etc.
+            The data which is loaded or stored depends on each plugin implementation.
+        """,
+    )
+    plugin.add_argument(
+        "--no-plugin-sideloading",
+        action="store_true",
+        help="""
+            Disable automatic sideloading of third-party plugins from the default location.
+
+            See the plugin-sideloading documentation for where third-party plugins are loaded from.
+        """,
+    )
+    plugin.add_argument(
+        "--plugin-dir",
+        dest="plugin_dirs",
+        metavar="DIRECTORY",
+        action="append",
+        help="""
+            Load additional plugins from this directory.
+
+            Can be set multiple times to load plugins from multiple directories.
+        """,
+    )
+    plugin.add_argument(
+        "--plugin-dirs",
+        metavar="DIRECTORY",
+        type=comma_list,
+        action="extend",
+        help="""
+            Load additional plugins from a list of comma-separated directories. (deprecated)
+        """,
+    )
+
     network = parser.add_argument_group("Network arguments")
     network.add_argument(
         "--interface",
@@ -654,6 +688,7 @@ def build_parser():
             This option will instead let the player decide when to exit.
         """,
     )
+    # noinspection PyTypeChecker
     player.add_argument(
         "-t",
         "--title",
@@ -665,8 +700,7 @@ def build_parser():
             as well as the "Plugins" section for the list of metadata variables defined in each plugin.
 
             Only the following players are supported:
-
-            {", ".join(sorted(PlayerOutput.PLAYERS.keys()))}
+            {"".join(f"{chr(0x0A)}            - {pn}" for pn in sorted([p.NAME for p in PlayerArgs.PLAYERS], key=str.lower))}
 
             Example:
 
@@ -739,6 +773,7 @@ def build_parser():
     )
     output.add_argument(
         "--fs-safe-rules",
+        metavar="{POSIX,Windows}",
         choices=["POSIX", "Windows"],
         type=str,
         help="""
@@ -764,6 +799,15 @@ def build_parser():
             When using --output or --record, always write to file even if it already exists (overwrite).
         """,
     )
+    output.add_argument(
+        "--skip",
+        action="store_true",
+        help="""
+            When using --output or --record, never write to file if it already exists (don't prompt).
+
+            Takes precedence over --force.
+        """,
+    )
     output.add_argument(
         "--progress",
         metavar="{yes,force,no}",
@@ -816,13 +860,16 @@ def build_parser():
     stream.add_argument(
         "--retry-streams",
         metavar="DELAY",
-        type=num(float, gt=0),
+        type=num(float, ge=0),
         help="""
             Retry fetching the list of available streams until streams are found
-            while waiting `DELAY` second(s) between each attempt. If unset, only one
-            attempt will be made to fetch the list of streams available.
+            while waiting `DELAY` second(s) between each attempt.
 
-            The number of fetch retry attempts can be capped with --retry-max.
+            The number of retry attempts can be capped with --retry-max.
+            A default value of ``1`` is implied for non-zero values of --retry-max.
+
+            If both --retry-streams and --retry-max are set to `0`, then only one attempt will be made
+            to fetch the list of available streams. This is the default behavior.
         """,
     )
     stream.add_argument(
@@ -830,10 +877,10 @@ def build_parser():
         metavar="COUNT",
         type=num(int, ge=0),
         help="""
-            When using --retry-streams, stop retrying the fetch after `COUNT` retry
-            attempt(s). Fetch will retry infinitely if `COUNT` is zero or unset.
+            Stop fetching the list of available streams after `COUNT` retry attempt(s).
 
-            If --retry-max is set without setting --retry-streams, the delay between retries will default to 1 second.
+            A value of `0` makes Streamlink fetch streams indefinitely if --retry-streams is set to a non-zero value.
+            If --retry-streams is unset, then the default delay between fetching available streams is 1 second.
         """,
     )
     stream.add_argument(
@@ -957,6 +1004,41 @@ def build_parser():
             Default is 10.0.
         """,
     )
+    transport.add_argument(
+        "--stream-segmented-duration",
+        type=hours_minutes_seconds_float,
+        metavar="[[XX:]XX:]XX[.XX] | [XXh][XXm][XX[.XX]s]",
+        help="""
+            Limit the output duration of segmented streams, like HLS and DASH.
+            The actual duration may be slightly longer, as it is rounded to the nearest segment.
+
+            Set to 0 to disable.
+
+            Default is 0.
+        """,
+    )
+    transport.add_argument(
+        "--stream-segmented-queue-deadline",
+        metavar="FACTOR",
+        type=num(float, ge=0.0),
+        help="""
+            A multiplication factor of the time frame in which new segments must be queued in order to prevent playback issues
+            due to lack of video/audio data. If this segment-queue-deadline has not been met, the stream will be stopped early.
+
+            The intention of this segment-queue-deadline is to be able to stop early when the end of a stream is not announced
+            by the server, so Streamlink doesn't have to wait until a buffer read-timeout occurs. See --stream-timeout.
+
+            The base time this multiplication factor is applied to depends on the specific
+            stream implementation and the respective values returned by the streaming server.
+            This deadline check is done after trying to fetch new data.
+
+            Set to ``0`` to disable.
+
+            Default is 3.0.
+
+            By default, wait three times as long for new segments to be made available than the server's advertised time frame.
+        """,
+    )
     transport.add_argument(
         "--stream-timeout",
         type=num(float, gt=0),
@@ -1034,19 +1116,9 @@ def build_parser():
     transport_hls.add_argument(
         "--hls-segment-queue-threshold",
         metavar="FACTOR",
-        type=num(float, ge=0),
+        type=num(float, ge=0.0),
         help="""
-            The multiplication factor of the HLS playlist's target duration after which the stream will be stopped early
-            if no new segments were queued after refreshing the playlist (multiple times). The target duration defines the
-            maximum duration a single segment can have, meaning new segments must be available during this time frame,
-            otherwise playback issues can occur.
-
-            The intention of this queue threshold is to be able to stop early when the end of a stream doesn't get
-            announced by the server, so Streamlink doesn't have to wait until a read-timeout occurs. See --stream-timeout.
-
-            Set to ``0`` to disable.
-
-            Default is 3.
+            Deprecated in favor of --stream-segmented-queue-deadline.
         """,
     )
     transport_hls.add_argument(
@@ -1118,10 +1190,7 @@ def build_parser():
         type=hours_minutes_seconds_float,
         metavar="[[XX:]XX:]XX[.XX] | [XXh][XXm][XX[.XX]s]",
         help="""
-            Limit the playback duration, useful for watching segments of a stream.
-            The actual duration may be slightly longer, as it is rounded to the nearest HLS segment.
-
-            Default is unlimited.
+            Deprecated in favor of --stream-segmented-duration.
         """,
     )
     transport_hls.add_argument(
@@ -1244,6 +1313,18 @@ def build_parser():
             Enable the `-start_at_zero` FFmpeg option when using --ffmpeg-copyts.
         """,
     )
+    transport_ffmpeg.add_argument(
+        "--ffmpeg-validation-timeout",
+        type=float,
+        metavar="SECONDS",
+        help="""
+            Timeout in seconds for FFmpeg version validation.
+
+            Default is 4.0.
+
+            Increase this on low-power systems if FFmpeg startup is slow.
+        """,
+    )
 
     http = parser.add_argument_group("HTTP options")
     http.add_argument(
@@ -1432,6 +1513,7 @@ def build_parser():
 # NOTE: arguments with `action=store_{true,false}` must set `default=None`
 _ARGUMENT_TO_SESSIONOPTION: list[tuple[str, str, Callable[[Any], Any] | None]] = [
     # generic arguments
+    ("no_plugin_cache", "no-plugin-cache", None),
     ("locale", "locale", None),
     # network arguments
     ("interface", "interface", None),
@@ -1450,16 +1532,17 @@ _ARGUMENT_TO_SESSIONOPTION: list[tuple[str, str, Callable[[Any], Any] | None]] =
     ("http_ssl_cert_crt_key", "http-ssl-cert", tuple),
     ("http_timeout", "http-timeout", None),
     # stream transport arguments
+    ("hls_duration", "hls-duration", None),  # deprecated options must come first
     ("ringbuffer_size", "ringbuffer-size", None),
     ("mux_subtitles", "mux-subtitles", None),
     ("stream_segment_attempts", "stream-segment-attempts", None),
     ("stream_segment_threads", "stream-segment-threads", None),
     ("stream_segment_timeout", "stream-segment-timeout", None),
+    ("stream_segmented_duration", "stream-segmented-duration", None),
     ("stream_timeout", "stream-timeout", None),
     ("hls_live_edge", "hls-live-edge", None),
     ("hls_live_restart", "hls-live-restart", None),
     ("hls_start_offset", "hls-start-offset", None),
-    ("hls_duration", "hls-duration", None),
     ("hls_playlist_reload_attempts", "hls-playlist-reload-attempts", None),
     ("hls_playlist_reload_time", "hls-playlist-reload-time", None),
     ("hls_segment_queue_threshold", "hls-segment-queue-threshold", None),
@@ -1486,6 +1569,7 @@ _ARGUMENT_TO_SESSIONOPTION: list[tuple[str, str, Callable[[Any], Any] | None]] =
     ("webbrowser_cdp_port", "webbrowser-cdp-port", None),
     ("webbrowser_cdp_timeout", "webbrowser-cdp-timeout", None),
     ("webbrowser_headless", "webbrowser-headless", None),
+    ("ffmpeg_validation_timeout", "ffmpeg-validation-timeout", None),
 ]
 
 
@@ -1501,7 +1585,7 @@ def setup_session_options(session: Streamlink, args: argparse.Namespace):
 def setup_plugin_args(session: Streamlink, parser: ArgumentParser):
     """Adds plugin argument data to the argument parser."""
 
-    plugin_args = parser.add_argument_group("Plugin options")
+    plugin_args = parser.add_argument_group("Plugin-specific options")
     for pname, arguments in session.plugins.iter_arguments():
         group = parser.add_argument_group(pname.capitalize(), parent=plugin_args)
 
